##
##  peg.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         peg
Summary:      Recursive-Descent Parser Generator for Parsing Expression Grammar (PEG) in C
URL:          http://piumarta.com/software/peg/
Vendor:       Ian Piumarta
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        CompilerCompiler
License:      MIT
Version:      0.1.20
Release:      20231130

#   list of sources
Source0:      http://piumarta.com/software/peg/peg-%{version}.tar.gz
Patch0:       peg.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    peg(1) and leg(1) are tools for generating recursive-descent
    parsers: programs that perform pattern matching on text. They
    processes a Parsing Expression Grammar (PEG) to produce a program
    that recognises legal sentences of that grammar. peg(1) processes
    PEGs written using the original syntax described by Ford while
    leg(1) processes PEGs written using slightly different syntax and
    conventions that are intended to make it an attractive replacement
    for parsers built with lex(1) and yacc(1). Unlike lex(1) and
    yacc(1), peg(1) and leg(1) support unlimited backtracking, provide
    ordered choice as a means for disambiguation, and can combine
    scanning (lexical analysis) and parsing (syntactic analysis) into a
    single activity.

%track
    prog peg = {
        version   = %{version}
        url       = http://piumarta.com/software/peg/
        regex     = peg-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   bootstrap tools
    touch peg.peg-c leg.c
    %{l_make} %{l_mflags} \
        CC="%{l_cc}" \
        OFLAGS="%{l_cflags -O}"

    #   re-build from scratch
    touch peg.peg leg.leg
    rm peg.o leg.o
    %{l_make} %{l_mflags} \
        CC="%{l_cc}" \
        OFLAGS="%{l_cflags -O}"

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -s -m 755 \
        peg leg $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        src/peg.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

